Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(566)

Unified Diff: lib/dom/src/native_DOMPublic.dart

Issue 10826304: Migrate to testRunner from layoutTestController. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/dom/src/native_DOMPublic.dart
diff --git a/lib/dom/src/native_DOMPublic.dart b/lib/dom/src/native_DOMPublic.dart
index 9bfac9e241c2421f767bf4fee71ebe4317c3c255..0c8b94f6617b7c2ac151cbd2fdb1bf037348bc2b 100644
--- a/lib/dom/src/native_DOMPublic.dart
+++ b/lib/dom/src/native_DOMPublic.dart
@@ -5,21 +5,21 @@
// This API is exploratory.
spawnDomFunction(Function topLevelFunction) => _Utils.spawnDomFunctionImpl(topLevelFunction);
-// layoutTestController implementation.
-// FIXME: provide a separate lib for layoutTestController.
+// testRunner implementation.
+// FIXME: provide a separate lib for testRunner.
-var _layoutTestController;
+var _testRunner;
-LayoutTestController get layoutTestController() {
- if (_layoutTestController === null)
- _layoutTestController = new LayoutTestController._(_NPObject.retrieve("layoutTestController"));
- return _layoutTestController;
+TestRunner get testRunner() {
+ if (_testRunner === null)
+ _testRunner = new TestRunner._(_NPObject.retrieve("testRunner"));
+ return _testRunner;
}
-class LayoutTestController {
+class TestRunner {
final _NPObject _npObject;
- LayoutTestController._(this._npObject);
+ TestRunner._(this._npObject);
display() => _npObject.invoke('display');
dumpAsText() => _npObject.invoke('dumpAsText');
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698